﻿/**
 * Real devices peer connection tests
 *
 * Shall include tests for:
 *   - createOffer
 *   - createAnswer
 *   - setLocalDescription
 *   - setRemoteDescription
 *   - updateIce
 *   - addIceCandidate
 *   - getting of any attribute on the peer connection object (done)
 *   - addStream (done)
 *   - removeStream
 *   - close
 *   - onnegotiationneeded
 *   - onicecandidate
 *   - onopen
 *   - onstatechange
 *   - onaddstream (done)
 *   - onremovestream
 *   - ongatheringchange
 *   - onicechange
 */

var firstPeerConnection = null;
var firstSDPOffer = null;
var secondPeerConnection = null;
var secondSDPOffer = null;

function turnOnLocalVideo(localVideo, constriants) {
	navigator.mozGetUserMedia(constriants, function(stream) {
		localVideo.mozSrcObject = stream;
		localVideo.play();
	}, function (err) {
		alert("Failed to start local video: " + err);
	});
}

function createPeerConnection1() {
	firstPeerConnection = new mozRTCPeerConnection();
}

function createPeerConnection2() {
	secondPeerConnection = new mozRTCPeerConnection();
}

function outputSDPOffers() {
	output = "firstSDPOffer: ";
	
	if(firstSDPOffer) {
		output += firstSDPOffer.type + " " + firstSDPOffer.sdp;
	} else {
		output += "null\n";
	}

	output += "secondSDPOffer: ";
	
	if(secondSDPOffer) {
		output += secondSDPOffer.type + " " + secondSDPOffer.sdp;
	} else {
		output += "null\n";
	}

	console.log(output);
	alert("Success - See console log");
}

function outputPeerConnectionAttributes(connectionObj) {
	
	if(connectionObj) {
		var output = "";
		
		output += "localDescription: ";
		
		if(connectionObj.localDescription) {
			output += connectionObj.localDescription.type + " " + connectionObj.localDescription.sdp;
		} else {
			output += "null\n";
		}

		output += "remoteDescription: ";
		
		if(connectionObj.remoteDescription) {
			output += connectionObj.remoteDescription.type + " " + connectionObj.remoteDescription.sdp;
		} else {
			output += "null\n";
		}

		output += "readyState: " + connectionObj.readyState + "\n";
		output += "iceGatheringState: " + connectionObj.iceGatheringState + "\n";
		output += "iceState: " + connectionObj.iceState + "\n";
		output += "localStreams length: " + connectionObj.localStreams.length + "\n";
		output += "remoteStreams length: " + connectionObj.remoteStreams.length + "\n";
		
		alert(output);
		
	} else {
		alert("Peer connection is null");
	}
	
}

function handleOnAddStreamForPeerConnection1() {
	if(firstPeerConnection) {
		firstPeerConnection.onaddstream = function(obj) {
			var pc1video1 = document.getElementById('pc1video');
			pc1video1.mozSrcObject = obj.stream;
			pc1video1.play();
		}
	} else {
		alert("Peer Connection needs to be created first");
	}
}

function handleOnAddStreamForPeerConnection2() {
	if(secondPeerConnection) {
		secondPeerConnection.onaddstream = function(obj) {
			var pc2video1 = document.getElementById('pc2video');
			pc2video1.mozSrcObject = obj.stream;
			pc2video1.play();
		}
	} else {
		alert("Peer Connection needs to be created first");
	}
}

function addStream(peerConnection, stream) {
	if(peerConnection) {
		peerConnection.addStream(stream);
	} else {
		alert("Peer Connection is null");
	}
}

function firstPeerConnectionOffer() {
	if(firstPeerConnection) {
		firstPeerConnection.createOffer(function(offer) {
			firstSDPOffer = offer;
		}, function(err) {
			alert("Create offer failed with: " + err);
		});
	} else {
		alert("First Peer Connection is null");
	}
}

function secondPeerConnectionOffer() {
	if(secondPeerConnection) {
		secondPeerConnection.createOffer(function(offer) {
			secondSDPOffer = offer;
		}, function(err) {
			alert("Create offer failed with: " + err);
		});
	} else {
		alert("Second Peer Connection is null");
	}
}

window.addEventListener("DOMContentLoaded", function(err) {
	document.getElementById('localVideo1OnVideoOnly').onclick = function() {
		var localVideo1 = document.getElementById('localvideo1');
		turnOnLocalVideo(localVideo1, {video: true});
	};
	document.getElementById('localVideo1OnAudioOnly').onclick = function() {
		var localVideo1 = document.getElementById('localvideo1');
		turnOnLocalVideo(localVideo1, {audio: true});
	};
	document.getElementById('localVideo1OnVideoAudio').onclick = function() {
		var localVideo1 = document.getElementById('localvideo1');
		turnOnLocalVideo(localVideo1, {video: true, audio: true});
	};
	document.getElementById('localVideo2OnVideoOnly').onclick = function() {
		var localVideo2 = document.getElementById('localvideo2');
		turnOnLocalVideo(localVideo2, {video: true});
	};
	document.getElementById('localVideo2OnAudioOnly').onclick = function() {
		var localVideo2 = document.getElementById('localvideo2');
		turnOnLocalVideo(localVideo2, {audio: true});
	};
	document.getElementById('localVideo2OnVideoAudio').onclick = function() {
		var localVideo2 = document.getElementById('localvideo2');
		turnOnLocalVideo(localVideo2, {video: true, audio: true});
	};
	document.getElementById('createPC1').onclick = function() {
		createPeerConnection1();
	};
	document.getElementById('createPC2').onclick = function() {
		createPeerConnection2();
	};

	document.getElementById('onaddstreamPC1').onclick = handleOnAddStreamForPeerConnection1;
	document.getElementById('onaddstreamPC2').onclick = handleOnAddStreamForPeerConnection2;

	document.getElementById('getpc1attributes').onclick = function () {
		outputPeerConnectionAttributes(firstPeerConnection);
	};
	document.getElementById('getpc2attributes').onclick = function () {
		outputPeerConnectionAttributes(secondPeerConnection);
	};
	document.getElementById('addstreamuser1pc1').onclick = function () {
		var localVideo1 = document.getElementById('localvideo1');
		addStream(firstPeerConnection, localVideo1.mozSrcObject);
	};
	document.getElementById('addstreamuser2pc1').onclick = function () {
		var localVideo2 = document.getElementById('localvideo2');
		addStream(firstPeerConnection, localVideo2.mozSrcObject);
	};
	document.getElementById('addstreamuser1pc2').onclick = function () {
		var localVideo1 = document.getElementById('localvideo1');
		addStream(secondPeerConnection, localVideo1.mozSrcObject);
	};
	document.getElementById('addstreamuser2pc2').onclick = function () {
		var localVideo2 = document.getElementById('localvideo2');
		addStream(secondPeerConnection, localVideo2.mozSrcObject);
	};

	document.getElementById('outputsdpoffers').onclick = outputSDPOffers;
	document.getElementById('pc1offer').onclick = firstPeerConnectionOffer;
	document.getElementById('pc2offer').onclick = secondPeerConnectionOffer;
});
